==> visualvm_2.0.7.orig.tar.xz: visualvm-2.0.7/visualvm/charts/src/org/graalvm/visualvm/charts/ChartFactory.java <==
/*
 * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 * 
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 * 
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package org.graalvm.visualvm.charts;

/**
 * Factory class to create custom charts.
 *
 * @author Jiri Sedlacek
 */
public final class ChartFactory {

    /**
     * Creates an instance of SimpleXYChartSupport representing a simple XY chart.
     *
     * @param descriptor chart descriptor
     * @return instance of SimpleXYChartSupport representing a simple XY chart
     */
    public static SimpleXYChartSupport createSimpleXYChart(SimpleXYChartDescriptor descriptor) {
        return new SimpleXYChartSupport(descriptor.getChartTitle(),
                                        descriptor.getXAxisDescription(),
                                        descriptor.getYAxisDescription(),
                                        descriptor.getChartType(),
                                        descriptor.getInitialYMargin(),
                                        descriptor.getItemNames(),
                                        descriptor.getItemColors(),
                                        descriptor.getLineWidths(),
                                        descriptor.getLineColors(),
                                        descriptor.getFillColors1(),
                                        descriptor.getFillColors2(),
                                        descriptor.getMinValue(),
                                        descriptor.getMaxValue(),
                                        descriptor.getChartFactor(),
                                        descriptor.getCustomFormat(),
                                        descriptor.areItemsHideable(),
                                        descriptor.getValuesBuffer(),
                                        descriptor.getDetailsItems());
    }

    
    private ChartFactory() {}

}

==> visualvm_2.1.5.orig.tar.xz: visualvm-2.1.5/visualvm/charts/src/org/graalvm/visualvm/charts/ChartFactory.java <==
/*
 * Copyright (c) 2007, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 * 
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 * 
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package org.graalvm.visualvm.charts;

/**
 * Factory class to create custom charts.
 *
 * @author Jiri Sedlacek
 */
public final class ChartFactory {

    /**
     * Creates an instance of SimpleXYChartSupport representing a simple XY chart.
     *
     * @param descriptor chart descriptor
     * @return instance of SimpleXYChartSupport representing a simple XY chart
     */
    public static SimpleXYChartSupport createSimpleXYChart(SimpleXYChartDescriptor descriptor) {
        return new SimpleXYChartSupport(descriptor.getChartTitle(),
                                        descriptor.getXAxisDescription(),
                                        descriptor.getYAxisDescription(),
                                        descriptor.getChartType(),
                                        descriptor.getInitialYMargin(),
                                        descriptor.getItemNames(),
                                        descriptor.getItemColors(),
                                        descriptor.getLineWidths(),
                                        descriptor.getLineColors(),
                                        descriptor.getFillColors1(),
                                        descriptor.getFillColors2(),
                                        descriptor.getMinValue(),
                                        descriptor.getMaxValue(),
                                        descriptor.getChartFactor(),
                                        descriptor.getCustomFormat(),
                                        descriptor.areItemsHideable(),
                                        descriptor.getValuesBuffer(),
                                        descriptor.getDetailsItems(),
                                        descriptor.getLimitYValue());
    }

    
    private ChartFactory() {}

}
